@@ -5,7 +5,7 @@
     use XML::Compile::Util qw/pack_type/;
     use List::Util qw/first/;
     use base qw(Catalyst::Model);
-    our $VERSION = '1.2';
+    our $VERSION = '1.3';
 
 
     __PACKAGE__->mk_accessors('transport');
@@ -26,9 +26,10 @@
         }
 
         if (ref $wsdl eq 'ARRAY') {
-            my $main = shift @{$wsdl};
+            my @wsdl = @{$wsdl};
+            my $main = shift @wsdl;
             $wsdl_obj = XML::Compile::WSDL11->new($main);
-            $wsdl_obj->addWSDL($_) for @{$wsdl};
+            $wsdl_obj->addWSDL($_) for @wsdl;
         } else {
             $wsdl_obj = XML::Compile::WSDL11->new($wsdl);
         }
